==> apache-polaris-1.1.0-incubating.tar.gz: apache-polaris-1.1.0-incubating/runtime/service/src/main/java/org/apache/polaris/service/context/catalog/PolarisCallContextCatalogFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.polaris.service.context.catalog;

import jakarta.enterprise.context.ApplicationScoped;
import jakarta.inject.Inject;
import jakarta.ws.rs.core.SecurityContext;
import java.util.HashMap;
import java.util.Map;
import org.apache.iceberg.CatalogProperties;
import org.apache.iceberg.catalog.Catalog;
import org.apache.polaris.core.auth.PolarisPrincipal;
import org.apache.polaris.core.context.CallContext;
import org.apache.polaris.core.entity.CatalogEntity;
import org.apache.polaris.core.entity.PolarisBaseEntity;
import org.apache.polaris.core.persistence.MetaStoreManagerFactory;
import org.apache.polaris.core.persistence.resolver.PolarisResolutionManifest;
import org.apache.polaris.core.persistence.resolver.ResolverFactory;
import org.apache.polaris.core.storage.cache.StorageCredentialCache;
import org.apache.polaris.service.catalog.iceberg.IcebergCatalog;
import org.apache.polaris.service.catalog.io.FileIOFactory;
import org.apache.polaris.service.events.PolarisEventListener;
import org.apache.polaris.service.task.TaskExecutor;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

@ApplicationScoped
public class PolarisCallContextCatalogFactory implements CallContextCatalogFactory {
  private static final Logger LOGGER =
      LoggerFactory.getLogger(PolarisCallContextCatalogFactory.class);

  private final TaskExecutor taskExecutor;
  private final FileIOFactory fileIOFactory;
  private final StorageCredentialCache storageCredentialCache;
  private final ResolverFactory resolverFactory;
  private final MetaStoreManagerFactory metaStoreManagerFactory;
  private final PolarisEventListener polarisEventListener;

  @Inject
  public PolarisCallContextCatalogFactory(
      StorageCredentialCache storageCredentialCache,
      ResolverFactory resolverFactory,
      MetaStoreManagerFactory metaStoreManagerFactory,
      TaskExecutor taskExecutor,
      FileIOFactory fileIOFactory,
      PolarisEventListener polarisEventListener) {
    this.storageCredentialCache = storageCredentialCache;
    this.resolverFactory = resolverFactory;
    this.metaStoreManagerFactory = metaStoreManagerFactory;
    this.taskExecutor = taskExecutor;
    this.fileIOFactory = fileIOFactory;
    this.polarisEventListener = polarisEventListener;
  }

  @Override
  public Catalog createCallContextCatalog(
      CallContext context,
      PolarisPrincipal polarisPrincipal,
      SecurityContext securityContext,
      final PolarisResolutionManifest resolvedManifest) {
    PolarisBaseEntity baseCatalogEntity =
        resolvedManifest.getResolvedReferenceCatalogEntity().getRawLeafEntity();
    String catalogName = baseCatalogEntity.getName();

    String realm = context.getRealmContext().getRealmIdentifier();
    String catalogKey = realm + "/" + catalogName;
    LOGGER.debug("Initializing new BasePolarisCatalog for key: {}", catalogKey);

    IcebergCatalog catalogInstance =
        new IcebergCatalog(
            storageCredentialCache,
            resolverFactory,
            metaStoreManagerFactory.getOrCreateMetaStoreManager(context.getRealmContext()),
            context,
            resolvedManifest,
            securityContext,
            taskExecutor,
            fileIOFactory,
            polarisEventListener);

    CatalogEntity catalog = CatalogEntity.of(baseCatalogEntity);
    Map<String, String> catalogProperties = new HashMap<>(catalog.getPropertiesAsMap());
    String defaultBaseLocation = catalog.getBaseLocation();
    LOGGER.debug(
        "Looked up defaultBaseLocation {} for catalog {}", defaultBaseLocation, catalogKey);

    if (defaultBaseLocation == null) {
      throw new IllegalStateException(
          String.format(
              "Catalog '%s' does not have a configured warehouse location. "
                  + "Please configure a default base location for this catalog.",
              catalogKey));
    }

    catalogProperties.put(CatalogProperties.WAREHOUSE_LOCATION, defaultBaseLocation);

    // TODO: The initialize properties might need to take more from CallContext and the
    // CatalogEntity.
    catalogInstance.initialize(catalogName, catalogProperties);

    return catalogInstance;
  }
}

==> apache-polaris-1.2.0-incubating.tar.gz: apache-polaris-1.2.0-incubating/runtime/service/src/main/java/org/apache/polaris/service/context/catalog/PolarisCallContextCatalogFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.polaris.service.context.catalog;

import jakarta.enterprise.context.ApplicationScoped;
import jakarta.inject.Inject;
import jakarta.ws.rs.core.SecurityContext;
import java.util.HashMap;
import java.util.Map;
import org.apache.iceberg.CatalogProperties;
import org.apache.iceberg.catalog.Catalog;
import org.apache.polaris.core.PolarisDiagnostics;
import org.apache.polaris.core.auth.PolarisPrincipal;
import org.apache.polaris.core.context.CallContext;
import org.apache.polaris.core.entity.CatalogEntity;
import org.apache.polaris.core.persistence.MetaStoreManagerFactory;
import org.apache.polaris.core.persistence.resolver.PolarisResolutionManifest;
import org.apache.polaris.core.persistence.resolver.ResolverFactory;
import org.apache.polaris.core.storage.cache.StorageCredentialCache;
import org.apache.polaris.service.catalog.iceberg.IcebergCatalog;
import org.apache.polaris.service.catalog.io.FileIOFactory;
import org.apache.polaris.service.events.listeners.PolarisEventListener;
import org.apache.polaris.service.task.TaskExecutor;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

@ApplicationScoped
public class PolarisCallContextCatalogFactory implements CallContextCatalogFactory {
  private static final Logger LOGGER =
      LoggerFactory.getLogger(PolarisCallContextCatalogFactory.class);

  private final PolarisDiagnostics diagnostics;
  private final TaskExecutor taskExecutor;
  private final FileIOFactory fileIOFactory;
  private final StorageCredentialCache storageCredentialCache;
  private final ResolverFactory resolverFactory;
  private final MetaStoreManagerFactory metaStoreManagerFactory;
  private final PolarisEventListener polarisEventListener;

  @Inject
  public PolarisCallContextCatalogFactory(
      PolarisDiagnostics diagnostics,
      StorageCredentialCache storageCredentialCache,
      ResolverFactory resolverFactory,
      MetaStoreManagerFactory metaStoreManagerFactory,
      TaskExecutor taskExecutor,
      FileIOFactory fileIOFactory,
      PolarisEventListener polarisEventListener) {
    this.diagnostics = diagnostics;
    this.storageCredentialCache = storageCredentialCache;
    this.resolverFactory = resolverFactory;
    this.metaStoreManagerFactory = metaStoreManagerFactory;
    this.taskExecutor = taskExecutor;
    this.fileIOFactory = fileIOFactory;
    this.polarisEventListener = polarisEventListener;
  }

  @Override
  public Catalog createCallContextCatalog(
      CallContext context,
      PolarisPrincipal polarisPrincipal,
      SecurityContext securityContext,
      final PolarisResolutionManifest resolvedManifest) {
    CatalogEntity catalog = resolvedManifest.getResolvedCatalogEntity();
    String catalogName = catalog.getName();

    String realm = context.getRealmContext().getRealmIdentifier();
    String catalogKey = realm + "/" + catalogName;
    LOGGER.debug("Initializing new BasePolarisCatalog for key: {}", catalogKey);

    IcebergCatalog catalogInstance =
        new IcebergCatalog(
            diagnostics,
            storageCredentialCache,
            resolverFactory,
            metaStoreManagerFactory.getOrCreateMetaStoreManager(context.getRealmContext()),
            context,
            resolvedManifest,
            securityContext,
            taskExecutor,
            fileIOFactory,
            polarisEventListener);

    Map<String, String> catalogProperties = new HashMap<>(catalog.getPropertiesAsMap());
    String defaultBaseLocation = catalog.getBaseLocation();
    LOGGER.debug(
        "Looked up defaultBaseLocation {} for catalog {}", defaultBaseLocation, catalogKey);

    if (defaultBaseLocation == null) {
      throw new IllegalStateException(
          String.format(
              "Catalog '%s' does not have a configured warehouse location. "
                  + "Please configure a default base location for this catalog.",
              catalogKey));
    }

    catalogProperties.put(CatalogProperties.WAREHOUSE_LOCATION, defaultBaseLocation);

    // TODO: The initialize properties might need to take more from CallContext and the
    // CatalogEntity.
    catalogInstance.initialize(catalogName, catalogProperties);

    return catalogInstance;
  }
}
